@@ -8,16 +8,18 @@ f.check.pars <- function( mcall, defaults ){
 params <- defaults
 params[names( mcall )] <- mcall
 #
+
 ## COLLECT IN LIST
-.info <- list( filename = 
-	params[["filename"]], 
-	filespecs = params[c("markers", "n.vars", "sep", "allele.sep", "na.strings", "subset")], 
-	model = params[c("design", "use.missing", "xchrom", "comb.sex", "maternal", "poo", "test.maternal", "scoretest")], 
-	variables = params[c("ccvar", "covar", "strata", "sex")],
-	haplos = params[c("reference", "response", "threshold", "max.haplos", "haplo.file")],
-	control = params[c("resampling", "max.EM.iter", "data.out", "verbose", "printout")]
-	)
-class(.info) <- "info"
+.info <- list( 
+	filename = params[["filename"]],
+	data = list(),
+	filespecs = params[c( "markers", "n.vars", "sep", "allele.sep", "na.strings" )], 
+	model = params[c( "design", "use.missing", "xchrom", "comb.sex", "maternal", "poo", "test.maternal", "scoretest" )], 
+	variables = params[c( "ccvar", "covar", "strata", "sex" )],
+	haplos = params[c( "reference", "response", "threshold", "max.haplos", "haplo.file" )],
+	control = params[c( "resampling", "max.EM.iter", "data.out", "verbose", "printout", "sel.markers" )]
+	 )
+class( .info ) <- "info"
 #
 ## DEFINE SPECIFIC VARIABLES
 .xchrom <- .info$model$xchrom
@@ -33,11 +35,11 @@ class(.info) <- "info"
 .allowed$control$resampling <- c( "no", "jackknife" )
 .allowed$model$comb.sex <- c( "males", "females", "single", "double" )
 #
-for(i in seq(along = .info)[-1]){# NO CHECK FOR filename
-	for(j in seq(along = .info[[i]])){
-		if(length(.info[[c(i,j)]]) == 1){# EXCLUDES NULL VALUES AND VECTOR VALUES (LIKE markers)
-			if(!is.element(.info[[c(i,j)]], .allowed[[c(i,j)]])){
-				stop(paste("The argument ", names(.info[[i]])[j], " has an invalid value. \nIt should be one of: \n", paste(.allowed[[c(i, j)]], collapse = ", "), sep = ""), call. = F)
+for( i in seq( along = .info )[-1] ){# NO CHECK FOR filename
+	for( j in seq( along = .info[[i]] ) ){
+		if( length( .info[[c( i,j )]] ) == 1 ){# EXCLUDES NULL VALUES AND VECTOR VALUES ( LIKE markers )
+			if( !is.element( .info[[c( i,j )]], .allowed[[c( i,j )]] ) ){
+				stop( paste( "The argument ", names( .info[[i]] )[j], " has an invalid value. \nIt should be one of: \n", paste( .allowed[[c( i, j )]], collapse = ", " ), sep = "" ), call. = F )
 			}
 		}
 	}
@@ -50,43 +52,55 @@ if( .info$model$design %in% c( "triad", "cc.triad" ) ) {
 if( .info$model$design == "cc" ){
 	.info$model$fam <- "c"
 }
-if(!is.name(.info$filename)){
-	## TEST WHETHER filename SPECIFICES A FILE
-	.filetest.f <- file_test("-f", .info$filename)
-	#
-	if(!.filetest.f) stop(paste(.info$filename, " is not a file.", sep = ""), call. = F)
-}
 #
-## SET VALUES IN THE gwaa.data CASE
-if(class(mcall$data) == "gwaa.data"){
-	#
-	## REPLACE "ALL" IF NECESSARY
-	if(identical(.info$filespecs$markers, "ALL")) .info$filespecs$markers <- seq(length.out = nsnps(mcall$data))
-	#
-	## SET CORRECT VALUES FOR COLUMN NUMBERS
-	if(.info$model$design == "triad"){
-		.info$filespecs$n.vars <- 3 * ncol(phdata(mcall$data)) + 1
-		if(.xchrom){
-			.info$variables$sex <- 7
-		}
+
+## SET VALUES
+# REPLACE "ALL" IF NECESSARY
+.info$control$sel.markers <- TRUE
+if( identical( .info$filespecs$markers, "ALL" ) ){
+	if( .info$model$design %in% c( "triad", "cc.triad" ) ){
+		ncol.per.marker <- 6
+	} else if( .info$model$design == "cc" ) {
+		ncol.per.marker <- 2
+	} else {
+		stop( "Given design: ", .info$model$design, " is not recognized!", call. = FALSE )
 	}
-	if(.info$model$design == "cc.triad"){
-		.info$filespecs$n.vars <- 3 * ncol(phdata(mcall$data)) + 1
-		.info$variables$ccvar <- 10
-		if(.xchrom){
-			.info$variables$sex <- 7
-		}
+	
+	if( class( mcall$data ) == "haplin.ready" ){
+		.info$filespecs$markers <- seq( length.out = sum( unlist( lapply( mcall$data$gen.data, ncol ) ) )/ncol.per.marker )
+		attr( mcall$data, "sel.markers" ) <- FALSE
 	}
-	if(.info$model$design == "cc"){
-		.info$filespecs$n.vars <- ncol(phdata(mcall$data)) + 1
-		.info$variables$ccvar <- 4
-		if(.xchrom){
-			.info$variables$sex <- 3
+	.info$control$sel.markers <- FALSE
+}
+
+# SET CORRECT VALUES FOR COLUMN NUMBERS
+.info$filespecs$n.vars <- 0
+if( class( mcall$data ) == "haplin.ready" ){
+	if( !is.null( mcall$data$cov.data ) ){
+		.info$filespecs$n.vars <- ncol( mcall$data$cov.data )		
+		if( .xchrom ){
+			if( any( .haplinEnv$sex.column %in% colnames( mcall$data$cov.data ) ) ){
+				.info$variables$sex <- match( .haplinEnv$sex.column, colnames( mcall$data$cov.data ) )
+			} else { 
+				stop( "The 'xchrom' parameter is set but the data does not contain information about sex!", call. = FALSE )
+			}
+		}
+		if( .ccdesign ){
+			# Get ccvar from haplin argument if present, 
+			# else use cc.c from cov.data
+			if(is.numeric(mcall$ccvar)){
+				.ccvar <- mcall$ccvar
+			}else if(is.character(mcall$ccvar)){
+				.ccvar <- match( mcall$ccvar, colnames( mcall$data$cov.data ) )
+			} else {
+				.ccvar <- match( .haplinEnv$cc.column, colnames( mcall$data$cov.data ) )
+			}
+			if(is.na(.ccvar) || (.ccvar <= 0.01) || (.ccvar >= ncol(mcall$data$cov.data) + 0.01)) stop("'ccvar' must specify a column name or position in the covariate data frame", call. = FALSE)
+			.info$variables$ccvar <- .ccvar
 		}
 	}
 }
 
-#
 ## ONLY USE response = "mult", AND DISALLOW poo, FOR MALES ONLY IN xchrom
 if( .xchrom && !is.null( .info$model$comb.sex ) && .info$model$comb.sex == "males" ){
 	if( .info$haplos$response != "mult" ){
@@ -103,7 +117,7 @@ if( .info$model$poo ){
 		stop( 'parent-of-origin effects not available when design = "cc"', call. = F )
 	}
 	if( .info$haplos$reference == "reciprocal" ){
-		warning( 'Can only ( for the time being ) use reference = "ref.cat" or "population" when poo == TRUE. Has been changed to "ref.cat".', call. = F )
+		warning( 'Can only (for the time being) use reference = "ref.cat" or "population" when poo == TRUE. Has been changed to "ref.cat".', call. = F )
 		.info$haplos$reference <- "ref.cat"
 	}
 }
@@ -114,8 +128,6 @@ if( .ccdesign ){
 	if( is.null( .info$variables$ccvar ) ){
 		stop( 'Parameter "ccvar" must be specified when using design "cc.triad" or "cc"!', call. = F )
 	}
-	if(.info$filespecs$n.vars == 0) stop('Parameter "n.vars" must be specified when using design "cc.triad" or "cc"!', call. = F)
-	if(.info$variables$ccvar > .info$filespecs$n.vars) stop('Parameter "n.vars" must be at least as large as parameter "ccvar"!', call. = F)
 }else{
 	if( !is.null( .info$variables$ccvar ) )stop( 'Parameter "ccvar" should only be specified when using design "cc.triad" or "cc"!', call. = F )
 }
@@ -124,7 +136,7 @@ if( .ccdesign ){
 if( !is.logical( .xchrom ) ){
 	stop( 'Argument "xchrom" must be a logical ( either "TRUE" or "FALSE" )', call. = F )
 }
-if( .xchrom ){
+if( F & .xchrom ){
 	if( .info$filespecs$n.vars == 0 ){
 		stop( 'Argument "n.vars" must be at least 1 to allow for a sex variable when "xchrom = TRUE"', call. = F )
 	}
@@ -134,9 +146,6 @@ if( .xchrom ){
 	if( .info$variables$sex > .info$filespecs$n.vars ){
 		stop( 'Argument "sex" cannot be larger than "n.vars"', call. = F )
 	}
-	#if( .info$model$design == "cc" ) stop( 'The "cc" design is not ( yet ) implemented for x-chromosomes', call. = F )
-	#if( .info$model$maternal ) stop( '"xchrom = TRUE" cannot currently be used with "maternal = TRUE"', call. = F )
-	#if( .info$haplos$response == "xinact" ) stop( 'Response "xinact" is only intended for the X-chromosome!', call. = F )
 }
 #
 if( F ){
@@ -157,14 +166,6 @@ if( .info$model$scoretest == "only" & ( .info$control$data.out == "full" ) ){
 ## CHECK VALUES FOR MARKERS
 if( !is.numeric( .info$filespecs$markers ) & !identical( .info$filespecs$markers, "ALL" ) ) stop( '"markers" argument must be either "ALL" ( default ) or an integer value.', call. = F ) 
 #
-##
-#
-## ONLY USE response = "mult" FOR cc ( FOR NOW ) ( HUSKER IKKE HVORFOR?? )
-#if( ( .info$model$design == "cc" ) & ( .info$haplos$response != "mult" ) ){
-#	warning( 'Can only use response = "mult" with design = "cc" ( for now... ). Has been changed to "mult".', call. = F )
-#	.info$haplos$response <- "mult"
-#}
-#
 ## NO MATERNAL EFFECTS WITH PURE cc
 if( ( .info$model$design == "cc" ) & ( .info$model$maternal ) ) stop( 'Cannot use maternal = TRUE with design = "cc"', call. = F )
 #
@@ -177,11 +178,33 @@ if( ( .info$haplos$response %in% c( "mult" ) ) & is.element( .info$haplos$refere
 ## IF test.maternal IS TRUE, MAKE SURE maternal IS ALSO TRUE
 if( .info$model$test.maternal ) .info$model$maternal <- TRUE
 
+## check name of given strata - should pick the env.exposure of the child!
+if( !is.null( .info$variables$strata ) ){
+	if( length( .info$variables$strata ) != 1 ){
+		stop( "You gave more than one 'stratum'!", call. = FALSE )
+	}
+	if( !is.numeric( .info$variables$strata ) ){
+		which.col.stratum <- match( paste0( .info$variables$strata, ".c" ), colnames( mcall$data$cov.data ) )
+		if( is.na( which.col.stratum ) ){
+			stop( "The given stratum name: ", .info$variables$strata, " doesn't match any of the covariate column names!", call. = FALSE )
+		}
+		.info$variables$strata <- which.col.stratum
+	}
+}
 
-## TEST OM covar, ccvar etc ER MINDRE ENN ELLER LIK n.vars, om de er heltall etc.?
-#
-# DENNE TESTEN KUNNE IKKE VARE MED, SIDEN f.check.pars OGSAA KALLES AV haplinSlide og haplinStrat:
-#if( !is.null( .info$variables$covar ) ) stop( 'Argument "covar" not currently implemented in "haplin", \nonly in "haplinStrat" and in "haplinSlide". \n( The latter needs "strat = TRUE" )', call. = F )
+## If any of the parameters in 'info' were not set, there might be 'NAs' in the list, so let's remove it before returning
+check.nas <- lapply( .info[ -(1:2) ], function(x){ any(is.na( names( x ) )) } )
+if( any( unlist( check.nas ) ) ){
+	cur.info <- .info[ -(1:2) ]
+	which.nas <- which( unlist( check.nas ) )
+	for( i in which.nas ){
+		cur.list <- cur.info[[ i ]]
+		which.nas2 <- which( is.na( names( cur.list ) ) )
+		fixed.list <- cur.list[ -which.nas2 ]
+		cur.info[[ i ]] <- fixed.list
+	}
+	.info[ -(1:2) ] <- cur.info
+}
 
 return( .info )
 
